@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.045'; # VERSION
+our $VERSION = '0.047'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -24,7 +24,6 @@ sub opt_spec {
 
     return (
         [ 'description|d=s' => 'Brief description of the stack' ],
-        [ 'dryrun'          => 'Do not commit any changes'      ],
     );
 
 
@@ -66,7 +65,7 @@ App::Pinto::Command::copy - create a new stack by copying another
 
 =head1 VERSION
 
-version 0.045
+version 0.047
 
 =head1 SYNOPSIS
 
@@ -97,12 +96,6 @@ will be forced to lowercase.
 
 Annotates the new stack with a brief description of its purpose.
 
-=item --dryrun
-
-Go through all the motions, but do not actually commit any changes to
-the repository.  Use this option to see how operations would
-potentially impact the stack.
-
 =back
 
 =head1 AUTHOR
