@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.045'; # VERSION
+our $VERSION = '0.047'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -19,7 +19,6 @@ sub opt_spec {
 
     return (
         ['default'              => 'mark stack as the default'     ],
-        [ 'dryrun'              => 'Do not commit any changes'     ],
         ['properties|prop|P=s%' => 'name=value pairs of properties'],
     );
 }
@@ -62,7 +61,7 @@ App::Pinto::Command::edit - change stack properties
 
 =head1 VERSION
 
-version 0.045
+version 0.047
 
 =head1 SYNOPSIS
 
@@ -94,12 +93,6 @@ static index file for your repository.  DO NOT CHANGE THE DEFAULT STACK
 WITHOUT DUE DILLIGENCE.  It has broad impact, especially if your
 repository has multiple users.
 
-=item --dryrun
-
-Go through all the motions, but do not actually commit any changes to
-the repository.  Use this option to see how operations would
-potentially impact the stack.
-
 =item --properties name1=value1
 
 =item --prop name1=value1
