@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.045'; # VERSION
+our $VERSION = '0.047'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -19,7 +19,6 @@ sub opt_spec {
     my ($self, $app) = @_;
 
     return (
-        [ 'dryrun'    => 'Do not commit any changes'            ],
         [ 'stack|s=s' => 'Stack from which to unpin the target' ],
     );
 }
@@ -48,7 +47,7 @@ App::Pinto::Command::unpin - free packages that have been pinned
 
 =head1 VERSION
 
-version 0.045
+version 0.047
 
 =head1 SYNOPSIS
 
@@ -84,12 +83,6 @@ or ';') will be ignored.
 
 =over 4
 
-=item --dryrun
-
-Go through all the motions, but do not actually commit any changes to
-the repository.  Use this option to see how upgrades would potentially
-impact the stack.
-
 =item --stack=NAME
 
 Unpins the package on the stack with the given NAME.  Defaults to the
